Skip to main content

Cross-platform dictionary and vocabulary building command line tool

platforms


Pyvoc

Use it to improve your english vocabulary, brush up some word meanings or as a simple command line dictionary.


Jump to:

Installation

Install it using pip. Just run:

pip3 install pyvoc

Usage

After installing pyvoc, run pyvoc -w word to automatically create necessary config files in your home directory.

  • Fetch meaning of word
pyvoc -w word
  • Fetch meaning of word and add it to vocabulary group:
pyoc word -a
  • Take quiz from vocabulary group 101 (default questions are 5):
pyvoc -q 101
  • Take quiz of 25 questions from vocabulary group 101 :
pyvoc -q 101 -n 25

read some more examples

➜ pyvoc -h
usage: pyvoc [-h] [-v] [-w <word>] [-a] [-g <group_num>] [-r <group_num>] [-q <group_num>] [-n <no_of_questions>] [-l]

Command line dictionary and vocabulary building tool.

optional arguments:
  -h, --help            show this help message and exit
  -v, --version         Print version of pyvoc and exit
  -w <word>             Give meaning of WORD
  -a, --add-word        Use to add WORD to vocabulary group
  -g <group_num>        Use to specify the vocabulary group no.(1-10) to add the WORD to
  -r <group_num>        Revise the vocabulary group you mention
  -q <group_num>        Start quiz from the vocabulary group you mention
  -n <no_of_questions>  Mention the number of questions of quiz.
  -l, --list            Lists all vocabulary groups present

groups

pyvoc lets you add words to vocabulary groups, which you can later revise or take quiz from.

  • 3 custom groups of 800 words each (words taken from GRE and SAT preparation websites) already present. These groups are 101, 102 and 103.
  • 10 groups of 50 words are reserved for the user. These groups are 1 - 10.
  • you can specify a group from 1-10 using [-g] option.

Examples

add word to a specific group

pyvoc word -a -g 5

Fetch meaning of the word and add it to vocabulary group 5. Use this option to organize words however you like.

for example

  • alphabatically
  • words from books you have been reading
  • parts of speech
  • increasing difficulty

revise a group

pyvoc -r 7

Revise word meaning of vocabulary group 7(if present) in random order.


show group list

pyvoc --list

Lists all group numbers along with their size.

Metadata

Release files for pyvoc 1.4.0

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for pyvoc 1.4.0
File Size Uploaded
pyvoc-1.4.0.tar.gz 9.9 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for pyvoc 1.4.0
File Interpreter ABI Platform
pyvoc-1.4.0-py3-none-any.whl Python 3 none any Details

Total release size: 20.8 kB

Release files / pyvoc-1.4.0.tar.gz

Download URL pyvoc-1.4.0.tar.gz
Size 9.9 kB
Tags Source
SHA-256 checksum
How to use checksums
be51aef2380cdec7e30b3a4cc22e1a2178c12b111e59d95a43306dc8a7142f3f
BLAKE2b-256 checksum
How to use checksums
c4d113fbb044f30bbd6691d68821058b1955bc2af91ea464175e012aca3655f1
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/3.2.0 pkginfo/1.5.0.1 requests/2.24.0 setuptools/44.0.0 requests-toolbelt/0.9.1 tqdm/4.49.0 CPython/3.8.5

Release files / pyvoc-1.4.0-py3-none-any.whl

Download URL pyvoc-1.4.0-py3-none-any.whl
Size 10.9 kB
Tags Python 3
SHA-256 checksum
How to use checksums
d5a10bd618266aaf0452056a98606d9283bc06f77f489106d93aabd2d84fc82a
BLAKE2b-256 checksum
How to use checksums
3751f31891653a09029eb7dbc69be5ad5e6bd9f635fd2013a45b6f9310d834b2
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/3.2.0 pkginfo/1.5.0.1 requests/2.24.0 setuptools/44.0.0 requests-toolbelt/0.9.1 tqdm/4.49.0 CPython/3.8.5

Release history Release notifications | RSS feed

This release

1.4.0 This release

2 release files

1.3.1

2 release files

1.3.0

2 release files

1.2.0

2 release files

1.1.0

2 release files

1.0.0

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page